@@ -74,7 +74,7 @@ def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
                      'syn' : vivado_exp.ExperienceType.SYNTHESIS,
                      'impl': vivado_exp.ExperienceType.IMPLEMENTATION}
     exp_type = exp_type_dict[config['exp_type']] if 'exp_type' in config else vivado_exp.ExperienceType.IMPLEMENTATION
-    regout = (not (config['no_reg_out'].strip.lower() == "true")) if 'no_reg_out' in config else True
+    regout = (not (config['no_reg_out'].strip().lower() == "true")) if 'no_reg_out' in config else True
     exp = vivado_exp.Experiment(
         name,
         comp_path,
