@@ -40,8 +40,6 @@ def build_get_export_ip(exp):
         export_path = list(Path("./vivado_export/solution/impl/ip/").glob('*.zip'))[0]
         shutil.move(str(export_path.resolve()), str(pwd))
     return export_ip
- 
-
 
 class HDL(Enum):
     VHDL = (0, "vhdl", "vhd")
@@ -69,13 +67,14 @@ class Experiment:
                  hdl: HDL,
                  exp_type: ExperienceType,
                  pipeline: bool,
+                 inline: bool,
                  ap_ctrl_hs: bool,
+                 reg_out: bool = True,
                  keep_env: bool = False,
                  description: _opt_str = None,
                  version: _opt_str = None,
                  ip_lib: _opt_str = None,
-                 vendor: _opt_str = None,
-                 logger=None
+                 vendor: _opt_str = None
                  ):
         self._comp_path = comp_path
         self._comp_name = comp_name
@@ -89,7 +88,7 @@ class Experiment:
         self._vendor = vendor
         self._ip_lib = ip_lib
         self._version = version
-        self._logger = logger if logger is not None else logging.getLogger("vrs_log")
+        self._logger = logging.getLogger("vrs_log")
         self._hdl = hdl
         self._ap_ctrl_hs = ap_ctrl_hs
         self._csynth_res = None
@@ -97,6 +96,8 @@ class Experiment:
         self._keep_env = keep_env
         self._exp_name = exp_name
         self._pipeline = pipeline
+        self._inline = inline
+        self._reg_out = reg_out and self._inline
         self._before_del_lst = []
 
     @property
@@ -129,8 +130,10 @@ class Experiment:
                                 self._part,
                                 self._clock_period,
                                 pipeline and self._pipeline,
+                                self._inline,
                                 self._ap_ctrl_hs,
-                                depth_constraint
+                                depth_constraint,
+                                self._reg_out
                                 )
             vtcl.csynth_solution_script(vs)
             if self._exp_type == ExperienceType.CSYNTH_ONLY:
@@ -161,7 +164,7 @@ class Experiment:
 
             vivado_script = Path("vivado_hls_script.tcl")
             pipeline = self._pipeline and not (depth_constraint is not None and
-                                          depth_constraint == 1) 
+                                          depth_constraint <= 1) 
             self._generate_script(vivado_script, pipeline, depth_constraint)
             run_script(vivado_script)
 
@@ -174,15 +177,25 @@ class Experiment:
                 root = Path() / "vivado_hls_synthesis" / "solution" / "impl" 
                 vivado_report = (root / "report" / f"{self._hdl.get_name()}"
                                  / f"{self._comp_name}_export.xml").resolve()
-                if self._exp_type == ExperienceType.SYNTHESIS:
-                    vivado_timing_rpt = (root / self._hdl.get_name() / "report" /
-                                     f'{self._comp_name}_timing_synth.rpt').resolve()
-                elif self._exp_type == ExperienceType.IMPLEMENTATION:
-                    vivado_timing_rpt = (root / self._hdl.get_name() / "report" /
-                                     f'{self._comp_name}_timing_routed.rpt').resolve()
+              #  if self._exp_type == ExperienceType.SYNTHESIS:
+              #      vivado_timing_rpt = (root / self._hdl.get_name() / "report" /
+              #                       f'{self._comp_name}_timing_synth.rpt').resolve()
+              #  elif self._exp_type == ExperienceType.IMPLEMENTATION:
+              #      vivado_timing_rpt = (root / self._hdl.get_name() / "report" /
+              #                      f'{self._comp_name}_timing_routed.rpt').resolve()
+
+
                 self._syn_impl_res = vrpt.parse_impl_report(vivado_report)
-                if depth_constraint is not None and depth_constraint == 1:
-                    self._syn_impl_res['worst_case_latency'] = 1
+                if depth_constraint is not None and depth_constraint <= 1:
+                    suffix = "synth" if self._exp_type == ExperienceType.SYNTHESIS else "routed"
+                    self._syn_impl_res['worst_case_latency'] = depth_constraint
+                    if depth_constraint  == 0:
+                        vivado_timing_rpt = (root / self._hdl.get_name() / "report" /
+                                             f'{self._comp_name}_timing_paths_{suffix}.rpt').resolve()
+                        timing = vrpt.parse_timing_report(vivado_timing_rpt)
+                        self._syn_impl_res["timing"] = timing
+
+
 
             for callback in self._before_del_lst:
                 callback()
